@@ -19,6 +19,8 @@
 #'
 #' \code{reset}: Boolean specifying whether to reset the internal MCMC sampling algorithms to their initial state (in terms of self-adapting tuning parameters), and begin recording posterior sample chains anew. Specifying \code{reset = FALSE} allows the MCMC algorithm to continue running from where it left off, appending additional posterior samples to the already existing sample chains. Generally, \code{reset = FALSE} should only be used when the MCMC has already been run (default = TRUE).
 #'
+#' \code{resetMV}: Boolean specifying whether to begin recording posterior sample chains anew. This argument is only considered when using \code{reset = FALSE}.  Specifying \code{reset = FALSE, resetMV = TRUE} allows the MCMC algorithm to continue running from where it left off, but without appending the new posterior samples to the already existing samples, i.e. all previously obtained samples will be erased. This option can help reduce memory usage during burn-in (default = FALSE).
+#'
 #' \code{nburnin}: Number of initial, pre-thinning, MCMC iterations to discard (default = 0).
 #'
 #' \code{time}: Boolean specifying whether to record runtimes of the individual internal MCMC samplers.  When \code{time = TRUE}, a vector of runtimes (measured in seconds) can be extracted from the MCMC using the method \code{mcmc$getTimes()} (default = FALSE).
@@ -26,10 +28,12 @@
 #' \code{progressBar}: Boolean specifying whether to display a progress bar during MCMC execution (default = TRUE).  The progress bar can be permanently disabled by setting the system option \code{nimbleOptions(MCMCprogressBar = FALSE)}.
 #'
 #' Samples corresponding to the \code{monitors} and \code{monitors2} from the MCMCconf are stored into the interval variables \code{mvSamples} and \code{mvSamples2}, respectively.
-#' These may be accessed and converted into R matrix objects via:
+#' These may be accessed and converted into R matrix or list objects via:
 #' \code{as.matrix(mcmc$mvSamples)}
+#' \code{as.list(mcmc$mvSamples)}
 #' \code{as.matrix(mcmc$mvSamples2)}
-#'
+#' \code{as.list(mcmc$mvSamples2)}
+#' 
 #' The uncompiled MCMC function may be compiled to a compiled MCMC object, taking care to compile in the same project as the R model object, using:
 #' \code{Cmcmc <- compileNimble(Rmcmc, project = Rmodel)}
 #'
@@ -89,6 +93,7 @@
 #' Cmcmc <- compileNimble(Rmcmc, project=Rmodel)
 #' Cmcmc$run(10000)
 #' samples <- as.matrix(Cmcmc$mvSamples)
+#' samplesAsList <- as.list(Cmcmc$mvSamples)
 #' head(samples)
 #' WAIC <- Cmcmc$calculateWAIC(nburnin = 1000)
 #' }
@@ -144,6 +149,7 @@ buildMCMC <- nimbleFunction(
     run = function(
         niter                 = integer(),
         reset                 = logical(default = TRUE),
+        resetMV               = logical(default = FALSE), ## Allows resetting mvSamples when reset==FALSE
         time                  = logical(default = FALSE),
         progressBar           = logical(default = TRUE),
         ## reinstate samplerExecutionOrder as a runtime argument, once we support non-scalar default values for runtime arguments:
@@ -167,8 +173,13 @@ buildMCMC <- nimbleFunction(
         } else {
             if(nburnin != 0)   stop('cannot specify nburnin when using reset = FALSE.')
             if(dim(samplerTimes)[1] != length(samplerFunctions) + 1)   samplerTimes <<- numeric(length(samplerFunctions) + 1)   ## first run: default inititialization to zero
-            mvSamples_copyRow  <- getsize(mvSamples)
-            mvSamples2_copyRow <- getsize(mvSamples2)
+            if (resetMV) {
+                mvSamples_copyRow  <- 0
+                mvSamples2_copyRow <- 0                
+            } else {
+                mvSamples_copyRow  <- getsize(mvSamples)
+                mvSamples2_copyRow <- getsize(mvSamples2)
+            }
         }
         resize(mvSamples,  mvSamples_copyRow  + floor((niter-nburnin) / thinToUseVec[1]))
         resize(mvSamples2, mvSamples2_copyRow + floor((niter-nburnin) / thinToUseVec[2]))
@@ -268,7 +279,6 @@ buildMCMC <- nimbleFunction(
             if(is.nan(WAIC)) print('WAIC was calculated as NaN.  You may need to add monitors to model latent states, in order for a valid WAIC calculation.')
             returnType(double())
             return(WAIC)
-        }),
-    where = getLoadingNamespace()
+        })
 )
 
