@@ -764,6 +764,55 @@ test_that('conjugate Wishart setup', {
     
 })
 
+test_that('conjugate Wishart setup with scaling', {
+    set.seed(0)
+    
+    trueCor <- matrix(c(1, .3, .7, .3, 1, -0.2, .7, -0.2, 1), 3)
+    covs <- c(3, 2, .5)
+    tau <- 4
+    
+    trueCov = diag(sqrt(covs)) %*% trueCor %*% diag(sqrt(covs))
+    Omega = solve(trueCov) / tau
+    
+    n = 20
+    R = diag(rep(1,3))
+    mu = 1:3
+    Y = mu + t(chol(trueCov)) %*% matrix(rnorm(3*n), ncol = n)
+    M = 3
+    data <- list(Y = t(Y), n = n, M = M, mu = mu, R = R)
+    
+    code <- nimbleCode( {
+        for(i in 1:n) {
+            Y[i, 1:M] ~ dmnorm(mu[1:M], tmp[1:M,1:M])
+        }
+        tmp[1:M,1:M] <- tau * Omega[1:M,1:M]
+        Omega[1:M,1:M] ~ dwish(R[1:M,1:M], 4);
+    })
+    
+    newDf = 4 + n
+    newR = R + tcrossprod(Y - mu)*tau
+    OmegaTrueMean = newDf * solve(newR)
+    
+    wishRV <- array(0, c(M, M, 10000))
+    for(i in 1:10000) {
+        z <- t(chol(solve(newR))) %*% matrix(rnorm(3*newDf), ncol = newDf)
+        wishRV[ , , i] <- tcrossprod(z)
+    }
+    OmegaSimTrueSDs = apply(wishRV, c(1,2), sd)
+
+    m <- nimbleModel(code, data = data[1],constants=data[2:5],inits = list(Omega = OmegaTrueMean, tau = tau))
+    conf <- configureMCMC(m)
+    expect_equal(conf$getSamplers()[[1]]$name, "conjugate_dwish_dmnorm", info = "conjugate dmnorm-dwish with scaling not detected")
+    
+    test_mcmc(model = code, name = 'conjugate Wishart, scaled', data = data, seed = 0, numItsC = 1000, inits = list(Omega = OmegaTrueMean, tau = tau),
+              results = list(mean = list(Omega = OmegaTrueMean ),
+                             sd = list(Omega = OmegaSimTrueSDs)),
+              resultsTolerance = list(mean = list(Omega = matrix(.05, M,M)),
+                                      sd = list(Omega = matrix(0.06, M, M))), avoidNestedTest = TRUE)
+                                        # issue with Chol in R MCMC - probably same issue as in jaw-linear
+    
+})
+
 test_that('using RW_wishart sampler on non-conjugate Wishart node', {
     set.seed(0)
     trueCor <- matrix(c(1, .3, .7, .3, 1, -0.2, .7, -0.2, 1), 3)
@@ -867,6 +916,55 @@ test_that('using RW_wishart sampler on inverse-Wishart distribution', {
     expect_true(all(round(as.numeric(RWSD - conjSD), 9) == c(0.022803503, -0.010107015, 0.012342044, -0.010107015, 0.006191412, -0.000091101, 0.012342044, -0.000091101, 0.001340032)))
 })
 
+test_that('detect conjugacy when scaling Wishart, inverse Wishart cases', {
+    code <- nimbleCode({
+        mycov[1:p, 1:p]  <- lambda * Sigma[1:p,1:p] / eta
+        y[1:p] ~ dmnorm(z[1:p], cov = mycov[1:p, 1:p])
+        Sigma[1:p,1:p] ~ dinvwish(S[1:p,1:p], nu)
+    })
+    m  <- nimbleModel(code, constants = list(p = 3))
+    expect_identical(length(m$checkConjugacy('Sigma')), 1L, 'inverse-Wishart case')
+
+    code <- nimbleCode({
+        mycov[1:p, 1:p]  <- lambda * Sigma[1:p,1:p] / eta
+        y[1:p] ~ dmnorm(z[1:p], prec = mycov[1:p, 1:p])
+        Sigma[1:p,1:p] ~ dwish(S[1:p,1:p], nu)
+    })
+    m  <- nimbleModel(code, constants = list(p = 3))
+    expect_identical(length(m$checkConjugacy('Sigma')), 1L, 'Wishart case')
+
+    code <- nimbleCode({
+        mycov[1:p, 1:p]  <- lambda * Sigma[1:p,1:p] / eta
+        y[1:p] ~ dmnorm(z[1:p], cov = mycov[1:p, 1:p])
+        Sigma[1:p,1:p] ~ dwish(S[1:p,1:p], nu)
+    })
+    m  <- nimbleModel(code, constants = list(p = 3))
+    expect_identical(length(m$checkConjugacy('Sigma')), 0L, 'inverse-Wishart not-conj case')
+
+    code <- nimbleCode({
+        mycov[1:p, 1:p]  <- lambda * Sigma[1:p,1:p] / eta
+        y[1:p] ~ dmnorm(z[1:p], prec = mycov[1:p, 1:p])
+        Sigma[1:p,1:p] ~ dinvwish(S[1:p,1:p], nu)
+    })
+    m  <- nimbleModel(code, constants = list(p = 3))
+    expect_identical(length(m$checkConjugacy('Sigma')), 0L, 'Wishart not-conj case')
+
+    code <- nimbleCode({
+        mycov[1:p, 1:p]  <- lambda[1:p,1:p] * Sigma[1:p,1:p]
+        y[1:p] ~ dmnorm(z[1:p], cov = mycov[1:p, 1:p])
+        Sigma[1:p,1:p] ~ dinvwish(S[1:p,1:p], nu)
+    })
+    m  <- nimbleModel(code, constants = list(p = 3))
+    expect_identical(length(m$checkConjugacy('Sigma')), 0L, 'Wishart case')
+
+    code <- nimbleCode({
+        mycov[1:p, 1:p]  <- lambda[1:p,1:p] %*% Sigma[1:p,1:p]
+        y[1:p] ~ dmnorm(z[1:p], cov = mycov[1:p, 1:p])
+        Sigma[1:p,1:p] ~ dinvwish(S[1:p,1:p], nu)
+    })
+    m  <- nimbleModel(code, constants = list(p = 3))
+    expect_identical(length(m$checkConjugacy('Sigma')), 0L, 'Wishart case')
+})
 
 
 ## testing conjugate MVN updating with ragged dependencies;
@@ -938,9 +1036,8 @@ test_that('conjugate MVN with ragged dependencies', {
     
 
     expect_true(all(abs(pmean - obsmean) / pmean < 0.01), info = 'ragged dmnorm conjugate posterior mean')
-    expect_true(all(abs(pprec - obsprec) / pprec < 0.005), info = 'ragged dmnorm conjugate posterior precision')
-    
-    })
+    expect_true(all(abs(pprec - obsprec) / pprec < 0.005), info = 'ragged dmnorm conjugate posterior precision')    
+})
     
 ## testing binary sampler
 test_that('binary sampler setup', {
@@ -1059,8 +1156,14 @@ test_that('RW_multinomial sampler', {
     X         <- rmultinom(1, N, pVecX)[,1]
     Y         <- rmultinom(1, N, pVecY)[,1]
     Z         <- rbeta(nGroups, 1+X, 1+Y)
-    Xini      <- rmultinom(1, N, sample(pVecX))[,1]
-    Yini      <- rmultinom(1, N, sample(pVecY))[,1]
+    ## Hard code in the results of sample() since output from sample
+    ## changed as of R 3.6.0 to fix a long-standing bug in R.
+    smpX <- pVecX[c(2,1,4,3,5)]
+    smpY <- pVecY[c(1,4,2,3,5)]
+    fakeSample <- sample(pVecX)  # to keep random number stream as before
+    Xini      <- rmultinom(1, N, smpX)[,1]
+    fakeSample <- sample(pVecY)  # to keep random number stream as before
+    Yini      <- rmultinom(1, N, smpY)[,1]
     Constants <- list(nGroups=nGroups)
     Inits     <- list(X=Xini, Y=Yini, pVecX=pVecX, pVecY=pVecY, N=N)
     Data      <- list(Z=Z)
@@ -1228,174 +1331,6 @@ test_that('RW_dirichlet sampler more complicated', {
 })
 
 
-## testing dcar_normal sampling
-test_that('dcar_normal sampling', {
-    cat('===== Starting MCMC test dcar_normal sampling. =====')
-    
-    code <- nimbleCode({
-        alpha0 ~ dflat()
-        S[1:N] ~ car.normal(adj[1:L], weights[1:L], num[1:N], 3)
-        for(i in 1:N)
-            mu[i] <- alpha0 + S[i]
-        for(i in 1:2) {
-            log(lambda[i]) <- mu[i]
-            Y[i] ~ dpois(lambda[i])
-        }
-        Y[3] ~ dnorm(mu[3], 3)
-        ymean4 <- 5*mu[4]
-        Y[4] ~ dnorm(ymean4, 7)
-        ymean5 <- 2*mu[5]
-        Y[5] ~ dnorm(ymean5, 1)
-    })
-    
-    constants <- list(N = 6,
-                      num = c(3,4,4,3,2,2),
-                      adj = c(2,3,4,   1,3,5,6,   1,2,4,5,   1,3,6,  2,3,   2,4),
-                      weights = rep(1, 18),
-                      L = 18)
-    data <- list(Y = c(10,12,15,20,24))
-    inits <- list(alpha0 = 0,
-                  S = c(0,0,0,0,0,0))
-    
-    Rmodel <- nimbleModel(code, constants, data, inits)
-    conf <- configureMCMC(Rmodel)
-    Rmcmc <- buildMCMC(conf)
-    Cmodel <- compileNimble(Rmodel)
-    Cmcmc <- compileNimble(Rmcmc, project = Rmodel)
-    
-    niter <- 20
-    set.seed(0); Rmcmc$run(niter)
-    set.seed(0); Cmcmc$run(niter)
-    
-    Rsamples <- as.matrix(Rmcmc$mvSamples)
-    Csamples <- as.matrix(Cmcmc$mvSamples)
-    
-    sampleNames <- colnames(Rsamples)
-    
-    expect_true(all(Rsamples[, sampleNames] - Csamples[, sampleNames] == 0),
-                info = 'agreement between R and C sampling of dcar_normal')
-    
-    expect_equal(as.numeric(Csamples[20, sampleNames]),
-                 c(1.639127, 1.815422, 1.676655, 5.099797, 2.345276, 7.018026, 2.696936),
-                 tolerance = 1e-6,
-                 info = 'exact sample values for dcar_normal')
-})
-
-
-
-## testing dcar_proper density evaluation,
-## and generation of default values of C and M
-test_that('dcar_proper density evaluation', {
-    cat('===== Starting test dcar_proper density evaluations. =====')
-
-    x <- c(1, 3, 3, 4)
-    mu <- rep(3, 4)
-    adj <- c(2, 1,3, 2,4, 3)
-    num <- c(1, 2, 2, 1)
-    lp <- 0.004158475
-    expect_equal(dcar_proper(x, mu, adj=adj, num=num, tau=1, gamma=0), lp,
-                 info = 'C density evaluation for dcar_proper() omitting C and M')
-
-    weights <- rep(1, 6)
-    CM <- as.carCM(adj, weights, num)
-    C <- CM$C
-    M <- CM$M
-    expect_equal(dcar_proper(x, mu, C, adj, num, M, tau=1, gamma=0), lp,
-                 info = 'C density evaluation for dcar_proper() weights all one')
-
-    weights <- c(2, 2, 3, 3, 4, 4)
-    CM2 <- as.carCM(adj, weights, num)
-    C2 <- CM2$C
-    M2 <- CM2$M
-    lp2 <- 0.001050636
-    expect_equal(dcar_proper(x, mu, C2, adj, num, M2, tau=1, gamma=0), lp2,
-                 info = 'C density evaluation for dcar_proper() weights different')
-})
-
-
-
-## testing dcar_proper sampling
-test_that('dcar_proper sampling', {
-    cat('===== Starting MCMC test dcar_proper sampling. =====')
-
-    code <- nimbleCode({
-        tau ~ dgamma(0.001, 0.001)
-        gamma ~ dunif(-1, 1)
-        x[1:N] ~ dcar_proper(mu[1:N], adj=adj[1:L], num=num[1:N], tau=tau, gamma=gamma)
-        y[1] ~ dnorm(x[1], 1)
-        y[2] ~ dnorm(3*x[2] + 5, 10)
-        y[3] ~ dnorm(x[3]^2, 1)
-        y[4] ~ dnorm(x[4]^2, 10)
-    })
-
-    mu <- 1:4
-    adj <- c(2, 1, 3, 2, 4, 3)
-    num <- c(1, 2, 2, 1)
-    tau <- 1
-    gamma <- 0
-    y <- c(3, 6, 8, 10)
-    x <- rep(0, 4)
-    constants <- list(mu = mu, adj = adj, num = num, N = 4, L = 6)
-    data <- list(y = y)
-    inits <- list(tau = tau, gamma = gamma, x = x)
-
-    Rmodel <- nimbleModel(code, constants, data, inits)
-    Cmodel <- compileNimble(Rmodel)
-    lp <- -574.964
-    
-    expect_equal(calculate(Rmodel), lp, tol = 1E-5,
-                 info = 'calculate for dcar_proper()')
-    
-    expect_equal(calculate(Cmodel), lp, tol = 1E-5,
-                 info = 'calculate for dcar_proper(), compiled')
-    
-    weights <- rep(1, 6)
-    CM <- as.carCM(adj, weights, num)
-    C <- CM$C
-    M <- CM$M
-    Q <- tau * diag(1/M) %*% (diag(4) - gamma*CAR_calcCmatrix(C, adj, num))
-    lp <- dmnorm_chol(x, mu, chol = chol(Q), prec_param = TRUE, log = TRUE)
-    
-    expect_equal(calculate(Rmodel, 'x[1:4]'), lp,
-                 info = 'R density evaluation for dcar_proper()')
-    
-    expect_equal(calculate(Cmodel, 'x[1:4]'), lp,
-                 info = 'C density evaluation for dcar_proper()')
-
-    set.seed(0); xnew <- rmnorm_chol(n = 1, mu, chol = chol(Q), prec_param = TRUE)
-    set.seed(0); simulate(Rmodel, 'x[1:4]')
-    set.seed(0); simulate(Cmodel, 'x[1:4]')
-    
-    expect_equal(xnew, Rmodel$x, info = 'R dcar_proper() simulate function')
-    expect_equal(xnew, Cmodel$x, info = 'R dcar_proper() simulate function')
-    
-    Rmodel$x <- x
-    Cmodel$x <- x
-    
-    conf <- configureMCMC(Rmodel)
-    conf$addMonitors('x')
-    Rmcmc <- buildMCMC(conf)
-    Cmcmc <- compileNimble(Rmcmc, project = Rmodel)
-
-    niter <- 20
-    set.seed(0); Rmcmc$run(niter)
-    set.seed(0); Cmcmc$run(niter)
-
-    Rsamples <- as.matrix(Rmcmc$mvSamples)
-    Csamples <- as.matrix(Cmcmc$mvSamples)
-
-    sampleNames <- colnames(Rsamples)
-
-    expect_true(all(Rsamples[, sampleNames] - Csamples[, sampleNames] == 0),
-                info = 'agreement between R and C sampling of dcar_proper')
-
-    expect_equal(as.numeric(Csamples[20, sampleNames]),
-                 c(0.0978025, -0.6643286, 1.9510954, 0.2413084, 2.6684426, -3.2533691),
-                 tolerance = 1e-6,
-                 info = 'exact sample values for dcar_proper')
-})
-
-
 ## testing dmnorm-dnorm conjugacies we don't detect
 
 test_that('dnorm-dmnorm conjugacies NIMBLE fails to detect', {
@@ -1427,8 +1362,7 @@ test_that('dnorm-dmnorm conjugacies NIMBLE fails to detect', {
 ## dnorm prior in vectorized regression mean (inprod, matrix multiplication)
 
 test_that('NIMBLE detects dnorm-dnorm conjugacy via inprod() or %*%', {
-    ## do unit testing of cc_checkLinearity too
-    
+
     code <- nimbleCode({
         for(i in 1:n) 
             y[i] ~ dnorm(b0 + inprod(beta[1:p], X[i, 1:p]), 1)
@@ -1562,6 +1496,90 @@ test_that('NIMBLE detects dnorm-dnorm conjugacy via inprod() or %*%', {
     check <- nimble:::cc_checkLinearity(quote(b0 + inprod(structureExpr(beta[1], beta[2], beta[3]), X[1, 1:3])), 'beta[1]')
     expect_identical(check, list(offset = quote(b0 + structureExpr(beta[1], beta[2], beta[3]) * X[1, 1:3]),
                                  scale = quote(X[1, 1:3])))
+
+    ## check nested specifications
+    
+    code <- nimbleCode({
+        for(i in 1:n) 
+            y[i] ~ dnorm(b0 + inprod(zbeta[1:p], X[i, 1:p]), 1)
+        for(i in 1:p) {
+            beta[i] ~ dnorm(0, 1)
+            zbeta[i] <- z[i] * beta[i]
+        }
+        b0 ~ dnorm(0, 1)
+    })
+    constants <- list(n = 5, p = 3)
+    data <- list(y = rnorm(constants$n),
+                 X = matrix(rnorm(constants$n * constants$p), constants$n))
+    inits <- list(b0 = 1, beta = rnorm(constants$p))
+    m <- nimbleModel(code, data = data, constants = constants)
+    conf <- configureMCMC(m)
+    expect_identical(conf$getSamplers()[[1]]$name, 'conjugate_dnorm_dnorm',
+                                   info = "conjugacy with inprod not detected")
+   
+    code <- nimbleCode({
+        for(i in 1:n) 
+            y[i] ~ dnorm(b0 + inprod(zbeta[1:p], X[i, 1:p]), 1)
+        for(i in 1:p) {
+            beta[i] ~ dnorm(0, 1)
+            wbeta[i] <- a + w * beta[i]
+            zbeta[i] <- z[i] * wbeta[i]
+        }
+        b0 ~ dnorm(0, 1)
+    })
+    constants <- list(n = 5, p = 3)
+    data <- list(y = rnorm(constants$n),
+                 X = matrix(rnorm(constants$n * constants$p), constants$n))
+    inits <- list(b0 = 1, beta = rnorm(constants$p))
+    m <- nimbleModel(code, data = data, constants = constants)
+    conf <- configureMCMC(m)
+    expect_identical(conf$getSamplers()[[1]]$name, 'conjugate_dnorm_dnorm',
+                                   info = "conjugacy with inprod not detected")
+
+    code <- nimbleCode({
+        for(i in 1:n) 
+            y[i] ~ dnorm((X[i, 1:p] %*% zbeta[1:p])[1], 1)
+        for(i in 1:p) {
+            beta[i] ~ dnorm(0, 1)
+            zbeta[i] <- z[i] * beta[i]
+        }
+    })
+    constants <- list(n = 5, p = 3)
+    data <- list(y = rnorm(constants$n),
+                 X = matrix(rnorm(constants$n * constants$p), constants$n))
+    inits <- list(b0 = 1, beta = rnorm(constants$p))
+    m <- nimbleModel(code, data = data, constants = constants)
+    conf <- configureMCMC(m)
+    expect_identical(conf$getSamplers()[[1]]$name, 'conjugate_dnorm_dnorm',
+                     info = "conjugacy with inprod not detected")
+
+   code <- nimbleCode({
+        for(i in 1:n) 
+            y[i] ~ dnorm(b0 + inprod(zbeta[1:p], X[i, 1:p]), 1)
+        for(i in 1:p) {
+            beta[i] ~ dnorm(0, 1)
+            wbeta[i] <- exp(w * beta[i])
+            zbeta[i] <- z[i] * wbeta[i]
+        }
+        b0 ~ dnorm(0, 1)
+    })
+    constants <- list(n = 5, p = 3)
+    data <- list(y = rnorm(constants$n),
+                 X = matrix(rnorm(constants$n * constants$p), constants$n))
+    inits <- list(b0 = 1, beta = rnorm(constants$p))
+    m <- nimbleModel(code, data = data, constants = constants)
+    conf <- configureMCMC(m)
+    expect_identical(conf$getSamplers()[[1]]$name, 'RW',
+                     info = "conjugacy with inprod mistakenly detected")
+
+    expect_identical(nimble:::cc_checkLinearity(
+        quote(structureExpr(z[1] * exp(w * beta[1]), z[2] * exp(w * beta[2]))),
+        'beta[2]'), NULL)
+    output <- nimble:::cc_checkLinearity(
+        quote(structureExpr(z[1] * exp(w * beta[1]), a + z[2] * (d + w * beta[2]))),
+        'beta[2]')
+    expect_identical(is.list(output), TRUE)  ## should be a list with scale/offset
+    
 })
 
 
@@ -1609,56 +1627,49 @@ test_that('slice sampler bails out of loop', {
 })
 
 
-test_that('CAR conjugacy checking new skipExpansionsNode system', {
-    ##
-    code <- nimbleCode({
-        S[1:N] ~ dcar_normal(adj[1:L], weights[1:L], numneighbours[1:N], 1)
-        for(i in 1:K) {
-            beta[i] ~ dnorm(0, 1)
-        }
-        for(i in 1:N){
-            eta[i] <- inprod(beta[1:K], x[1:K])
-            mu[i] <- S[i] + eta[i]
-            y[i] ~ dnorm(mu[i], 1)
-        }
-    })
-    ##
-    N <- 3
-    L <- 4
-    K <- 7
-    ##
-    constants <- list(N=N, L=L, K=K, adj=c(2,1,3,2), weights=rep(1,L), numneighbours=c(1,2,1))
-    data <- list(y = rep(0,N))
-    inits <- list(S = rep(0,N), beta = rep(0,K), x=1:K)
-    ##
-    Rmodel <- nimbleModel(code, constants, data, inits)
-    conf <- configureMCMC(Rmodel)
-    Rmcmc <- buildMCMC(conf)
-    ##
-    expect_true(class(Rmcmc) == 'MCMC')
-    expect_true(conf$samplerConfs[[8]]$name == 'CAR_normal')
-    expect_true(class(Rmcmc$samplerFunctions$contentsList[[8]]$componentSamplerFunctions$contentsList[[1]]) == 'CAR_scalar_conjugate')
-    expect_true(class(Rmcmc$samplerFunctions$contentsList[[8]]$componentSamplerFunctions$contentsList[[2]]) == 'CAR_scalar_conjugate')
-    expect_true(class(Rmcmc$samplerFunctions$contentsList[[8]]$componentSamplerFunctions$contentsList[[3]]) == 'CAR_scalar_conjugate')
-    ##
-    compiledList <- compileNimble(list(model=Rmodel, mcmc=Rmcmc))
-    Cmodel <- compiledList$model; Cmcmc <- compiledList$mcmc
-    ##
-    set.seed(0); Rsamples <- runMCMC(Rmcmc, 10)
-    set.seed(0); Csamples <- runMCMC(Cmcmc, 10)
-    ##
-    expectedSamples <- c(0.97357331, 0.07601302, 0.10439196, -0.37719856, 0.15912985, 0.03509085, -0.01162275, 0.17958068, -0.34811805, 0.10319592)
-    Rcolnames <- colnames(Rsamples)
-    ##
-    expect_true(all(round(as.numeric(Rsamples[10,Rcolnames]),8) == expectedSamples))
-    expect_true(all(round(as.numeric(Csamples[10,Rcolnames]),8) == expectedSamples))
+test_that('checkConjugacy corner case when linear scale is identically zero', {
+    targetNode <- 'beta[4]'
+    linearityCheckExpr <- quote(beta[4] * 0 * alpha.smrcent[3])
+    conjugacyCheck <- nimble:::cc_checkLinearity(linearityCheckExpr, targetNode)
+    expect_identical(conjugacyCheck, list(offset = 0, scale = 0))
+    
+    targetNode <- 'beta[4]'
+    linearityCheckExpr <- quote(beta[1] + beta[2] * 0 + beta[3] * alpha.smrcent[3] + beta[4] * 0 * alpha.smrcent[3] + alpha.stream[1] + alpha.family[3, 1])
+    conjugacyCheck <- nimble:::cc_checkLinearity(linearityCheckExpr, targetNode)
+    expect_identical(conjugacyCheck,
+                     list(offset = quote(beta[1] + beta[2] * 0 + beta[3] * alpha.smrcent[3] + alpha.stream[1] + alpha.family[3, 1]),
+                          scale = 0))
 })
 
+test_that('cc_checkScalar operates correctly', {
+    expect_true(cc_checkScalar(quote(lambda)))
+    expect_true(cc_checkScalar(quote(lambda*eta)))
+    expect_true(cc_checkScalar(quote(exp(lambda))))
+    expect_true(cc_checkScalar(quote(5+exp(lambda[2]))))
+
+    expect_false(cc_checkScalar(quote(exp(lambda[2:3]))))
+    expect_false(cc_checkScalar(quote(lambda[1:2,1:2])))
+    expect_false(cc_checkScalar(quote(lambda[1:2,1:2]/eta)))
+    expect_false(cc_checkScalar(quote(eta*(theta*lambda[1:2,1:2]))))
+    expect_false(cc_checkScalar(quote(lambda[1:2,1:2,1:5])))
+
+    expect_true(cc_checkScalar(quote(lambda[xi[i]])))
+    expect_true(cc_checkScalar(quote(lambda[xi[i],xi[j]])))
+    expect_false(cc_checkScalar(quote(lambda[xi[i]:3])))
+    expect_false(cc_checkScalar(quote(lambda[xi[i]:3,2])))
+
+    ## Ideally this case would evaluate to TRUE, but we would
+    ## have to handle knowing output dims of user-defined fxns.
+    expect_false(cc_checkScalar(quote(sum(lambda[1:5]))))
+    expect_false(cc_checkScalar(quote(foo(lambda))))
+
+})
 
 sink(NULL)
 
 if(!generatingGoldFile) {
     trialResults <- readLines(tempFileName)
+    trialResults <- trialResults[grep('Error in x$.self$finalize() : attempt to apply non-function', trialResults, invert = TRUE, fixed = TRUE)]
     correctResults <- readLines(system.file(file.path('tests', goldFileName), package = 'nimble'))
     compareFilesByLine(trialResults, correctResults)
 }
